@@ -766,8 +766,8 @@ public final class KeyUtils {
      * @param  expected The expected fingerprint if {@code null} or empty then returns a failure with the default
      *                  fingerprint.
      * @param  key      the {@link PublicKey} - if {@code null} then returns null.
-     * @return          SimpleImmutableEntry<Boolean, String> - key is success indicator, value is actual fingerprint,
-     *                  {@code null} if no key.
+     * @return          SimpleImmutableEntry&lt;Boolean, String> - key is success indicator, value is actual
+     *                  fingerprint, {@code null} if no key.
      * @see             #getDefaultFingerPrintFactory()
      * @see             #checkFingerPrint(String, Factory, PublicKey)
      */
@@ -780,8 +780,8 @@ public final class KeyUtils {
      *                  fingerprint.
      * @param  f        The {@link Factory} to be used to generate the default {@link Digest} for the key
      * @param  key      the {@link PublicKey} - if {@code null} then returns null.
-     * @return          SimpleImmutableEntry<Boolean, String> - key is success indicator, value is actual fingerprint,
-     *                  {@code null} if no key.
+     * @return          SimpleImmutableEntry&lt;Boolean, String> - key is success indicator, value is actual
+     *                  fingerprint, {@code null} if no key.
      */
     public static SimpleImmutableEntry<Boolean, String> checkFingerPrint(
             String expected, Factory<? extends Digest> f, PublicKey key) {
@@ -793,8 +793,8 @@ public final class KeyUtils {
      *                  fingerprint.
      * @param  d        The {@link Digest} to be used to generate the default fingerprint for the key
      * @param  key      the {@link PublicKey} - if {@code null} then returns null.
-     * @return          SimpleImmutableEntry<Boolean, String> - key is success indicator, value is actual fingerprint,
-     *                  {@code null} if no key.
+     * @return          SimpleImmutableEntry&lt;Boolean, String> - key is success indicator, value is actual
+     *                  fingerprint, {@code null} if no key.
      */
     public static SimpleImmutableEntry<Boolean, String> checkFingerPrint(String expected, Digest d, PublicKey key) {
         if (key == null) {
@@ -859,6 +859,8 @@ public final class KeyUtils {
     public static String getKeyType(Key key) {
         if (key == null) {
             return null;
+        } else if (key instanceof SshPublicKey) {
+            return ((SshPublicKey) key).getKeyType();
         } else if (key instanceof DSAKey) {
             return KeyPairProvider.SSH_DSS;
         } else if (key instanceof RSAKey) {
@@ -872,14 +874,9 @@ public final class KeyUtils {
             } else {
                 return curve.getKeyType();
             }
-        } else if (key instanceof SkEcdsaPublicKey) {
-            return SkECDSAPublicKeyEntryDecoder.KEY_TYPE;
-        } else if (SecurityUtils.EDDSA.equalsIgnoreCase(key.getAlgorithm())) {
+        } else if (SecurityUtils.EDDSA.equalsIgnoreCase(key.getAlgorithm())
+                || SecurityUtils.ED25519.equalsIgnoreCase(key.getAlgorithm())) {
             return KeyPairProvider.SSH_ED25519;
-        } else if (key instanceof SkED25519PublicKey) {
-            return SkED25519PublicKeyEntryDecoder.KEY_TYPE;
-        } else if (key instanceof OpenSshCertificate) {
-            return ((OpenSshCertificate) key).getKeyType();
         }
 
         return null;
@@ -1063,6 +1060,9 @@ public final class KeyUtils {
     }
 
     public static boolean compareKeys(PublicKey k1, PublicKey k2) {
+        if (Objects.equals(k1, k2)) {
+            return true;
+        }
         if ((k1 instanceof RSAPublicKey) && (k2 instanceof RSAPublicKey)) {
             return compareRSAKeys(RSAPublicKey.class.cast(k1), RSAPublicKey.class.cast(k2));
         } else if ((k1 instanceof DSAPublicKey) && (k2 instanceof DSAPublicKey)) {
@@ -1074,6 +1074,9 @@ public final class KeyUtils {
         } else if ((k1 != null) && SecurityUtils.EDDSA.equalsIgnoreCase(k1.getAlgorithm())
                 && (k2 != null) && SecurityUtils.EDDSA.equalsIgnoreCase(k2.getAlgorithm())) {
             return SecurityUtils.compareEDDSAPPublicKeys(k1, k2);
+        } else if ((k1 != null) && SecurityUtils.ED25519.equalsIgnoreCase(k1.getAlgorithm())
+                && (k2 != null) && SecurityUtils.ED25519.equalsIgnoreCase(k2.getAlgorithm())) {
+            return SecurityUtils.compareEDDSAPPublicKeys(k1, k2);
         } else if ((k1 instanceof SkED25519PublicKey) && (k2 instanceof SkED25519PublicKey)) {
             return compareSkEd25519Keys(SkED25519PublicKey.class.cast(k1), SkED25519PublicKey.class.cast(k2));
         } else if ((k1 instanceof OpenSshCertificate) && (k2 instanceof OpenSshCertificate)) {
@@ -1251,27 +1254,11 @@ public final class KeyUtils {
     }
 
     public static boolean compareSkEcdsaKeys(SkEcdsaPublicKey k1, SkEcdsaPublicKey k2) {
-        if (Objects.equals(k1, k2)) {
-            return true;
-        } else if (k1 == null || k2 == null) {
-            return false; // both null is covered by Objects#equals
-        } else {
-            return Objects.equals(k1.getAppName(), k2.getAppName())
-                    && Objects.equals(k1.isNoTouchRequired(), k2.isNoTouchRequired())
-                    && compareECKeys(k1.getDelegatePublicKey(), k2.getDelegatePublicKey());
-        }
+        return Objects.equals(k1, k2);
     }
 
     public static boolean compareSkEd25519Keys(SkED25519PublicKey k1, SkED25519PublicKey k2) {
-        if (Objects.equals(k1, k2)) {
-            return true;
-        } else if (k1 == null || k2 == null) {
-            return false; // both null is covered by Objects#equals
-        } else {
-            return Objects.equals(k1.getAppName(), k2.getAppName())
-                    && Objects.equals(k1.isNoTouchRequired(), k2.isNoTouchRequired())
-                    && SecurityUtils.compareEDDSAPPublicKeys(k1.getDelegatePublicKey(), k2.getDelegatePublicKey());
-        }
+        return Objects.equals(k1, k2);
     }
 
     public static String getSignatureAlgorithm(String chosenAlgorithm, PublicKey key) {
@@ -1284,4 +1271,10 @@ public final class KeyUtils {
             return chosenAlgorithm;
         }
     }
+
+    public static boolean isCertificateAlgorithm(String algorithm) {
+        synchronized (SIGNATURE_ALGORITHM_MAP) {
+            return SIGNATURE_ALGORITHM_MAP.containsKey(algorithm);
+        }
+    }
 }
